@@ -254,89 +254,6 @@ def cleardb(ctx, config, no_update):
 def set_db_name(ctx, DBNAME):
     Commands.invoke(ctx, 'set_setting', key="DBNAME", value=DBNAME)
 
-def __collect_other_turndb2dev_sql():
-    from .odoo_config import customs_dir
-    dir = customs_dir() / 'devscripts'
-    if not dir.exists():
-        return ""
-    sqls = []
-    for file in dir.glob("**/*.sql"):
-        sqls.append(file.read_text())
-    return "\n\n".join(sqls)
-
-def __turn_into_devdb(config, conn):
-    from .odoo_config import current_version
-    from .myconfigparser import MyConfigParser
-    myconfig = MyConfigParser(config.files['settings'])
-    env = dict(map(lambda k: (k, myconfig.get(k)), myconfig.keys()))
-
-    # encrypt password
-    env['DEFAULT_DEV_PASSWORD'] = __hash_odoo_password(env['DEFAULT_DEV_PASSWORD'])
-
-    sql_file = config.dirs['images'] / 'odoo' / 'config' / str(current_version()) / 'turndb2dev.sql'
-    sql = sql_file.read_text()
-
-    sql += __collect_other_turndb2dev_sql() or ""
-
-    sql = __replace_all_envs_in_str(sql, env)
-
-    critical = False
-    for line in sql.split("\n"):
-        if not line:
-            continue
-        if line.startswith("--set critical"):
-            critical = True
-            continue
-        elif line.startswith("--set not-critical"):
-            critical = False
-            continue
-
-        comment = re.findall(r'\/\*[^\*^\/]*\*\/', line)
-        if comment:
-
-            def ignore_line(comment):
-                comment = comment[2:-2]
-                if 'if-table-exists' in comment:
-                    table = comment.split("if-table-exists")[1].strip()
-                    res = _execute_sql(
-                        conn,
-                        (
-                            "select count(*) "
-                            "from information_schema.tables "
-                            "where table_schema='public' and "
-                            f"table_name='{table}'"
-                        ),
-                        fetchone=True
-                    )
-                    return not res[0]
-                elif 'if-column-exists' in comment:
-                    table, column = comment.split("if-column-exists")[1].strip().split(".")
-                    res = _execute_sql(
-                        conn,
-                        (
-                            "select count(*) "
-                            "from information_schema.columns "
-                            "where table_schema='public' and "
-                            f"table_name='{table.strip()}' and "
-                            "column_name='{column.strip()}' "
-                        ),
-                        fetchone=True
-                    )
-                    return not res[0]
-                return False
-
-            if any(list(
-                    ignore_line(comment) for comment in comment[0].split(
-                        ";"))):
-                continue
-        try:
-            print(line)
-            _execute_sql(conn, line)
-        except Exception:
-            if critical:
-                raise
-            msg = traceback.format_exc()
-            print("failed un-critical sql:", msg)
 
 @db.command()
 @pass_config
